<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xmlns:ext="materialExtensions" exclude-result-prefixes="ext">

  <xsl:output method="text"/>

  <xsl:variable name="separator" select="';'"/>

  <xsl:variable name="line-separator" select="'&#13;&#10;'"/>
  <xsl:variable name="linebig-decorator" select="'----------------------------------------------------&#13;&#10;'"/>
  <xsl:variable name="linesmall-decorator" select="'------------------------&#13;&#10;'"/>
  <xsl:variable name="page-header" select="' Athena Hard Copy Report '"/>
  <xsl:variable name="spacing" select="'   '"/>
  <xsl:variable name="onetab" select="'&#x9;'"/>
  <xsl:variable name="twotabs" select="'&#x9;&#x9;'"/>
  <xsl:variable name="threetabs" select="'&#x9;&#x9;&#x9;'"/>
  <xsl:variable name="fourtabs" select="'&#x9;&#x9;&#x9;&#x9;'"/>
  <xsl:variable name="fivetabs" select="'&#x9;&#x9;&#x9;&#x9;&#x9;'"/>


  <xsl:variable name="defaultOEValue" select="'0.000000'"/>
  <xsl:variable name="default2DigitDecValue" select="'0.00'"/>
  <xsl:variable name="defaultNoLabel" select="'No Label Found'"/>
  <xsl:variable name="assemblyInstances" select="'Assembly Instances:'"/>
 
  <xsl:template match="/">
    <xsl:if test="Project">
      <xsl:apply-templates select="Project" />
    </xsl:if>
  </xsl:template>

  <xsl:template match="Project">
    <xsl:value-of select="$linebig-decorator" />
    <xsl:value-of select="$page-header" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$linebig-decorator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="Name" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$linebig-decorator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Project Number</xsl:text>
    <xsl:value-of select="$twotabs" />
    <xsl:value-of select="ProjectNumber" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Project City</xsl:text>
    <xsl:value-of select="$twotabs" />
    <xsl:value-of select="CityName" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Roadway Paved Surface Area</xsl:text>
    <xsl:value-of select="$twotabs" />
    <xsl:value-of select="GrossFloorArea" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Building Lifespan</xsl:text>
    <xsl:value-of select="$onetab" />
    <xsl:value-of select="BuildingLifeSpan" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Building Type</xsl:text>
    <xsl:value-of select="$twotabs" />
    <xsl:value-of select="BuildingTypeName" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$linebig-decorator" />
    <xsl:text disable-output-escaping="yes">Project Description</xsl:text>
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$linesmall-decorator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="ProjectDescription" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$linebig-decorator" />
    <xsl:text disable-output-escaping="yes">Operational Energy</xsl:text>
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Electricity</xsl:text>
    <xsl:value-of select="$fourtabs" />
    <xsl:choose>
       <xsl:when test="string-length(OperationalEnergy/Electricity) > 0">
        <xsl:value-of select="OperationalEnergy/Electricity"/>
         <xsl:value-of select="$spacing" />
         <xsl:value-of select="OperationalEnergy/ElectricityUnit"/>
       </xsl:when>
       <xsl:otherwise>
         <xsl:value-of select="$defaultOEValue"/>
         <xsl:value-of select="$spacing" />
        <xsl:value-of select="OperationalEnergy/ElectricityUnit"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Natural Gas</xsl:text>
    <xsl:value-of select="$fourtabs" />
    <xsl:choose>
      <xsl:when test="string-length(OperationalEnergy/NaturalGas) > 0">
        <xsl:value-of select="OperationalEnergy/NaturalGas"/>
        <xsl:value-of select="$spacing" />
        <xsl:value-of select="OperationalEnergy/NaturalGasUnit"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$defaultOEValue"/>
        <xsl:value-of select="$spacing" />
        <xsl:value-of select="OperationalEnergy/NaturalGasUnit"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">LPG (Industrial Boiler)</xsl:text>
    <xsl:value-of select="$threetabs" />
    <xsl:choose>
      <xsl:when test="string-length(OperationalEnergy/LiquifiedPetrolumeGas) > 0">
        <xsl:value-of select="OperationalEnergy/LiquifiedPetrolumeGas"/>
        <xsl:value-of select="$spacing" />
        <xsl:value-of select="OperationalEnergy/LiquifiedPetrolumeGasUnit"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$defaultOEValue"/>
        <xsl:value-of select="$spacing" />
        <xsl:value-of select="OperationalEnergy/LiquifiedPetrolumeGasUnit"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Heavy Fuel Oil (Industrial Boiler)</xsl:text>
    <xsl:value-of select="$onetab" />
    <xsl:choose>
      <xsl:when test="string-length(OperationalEnergy/HeavyFuel) > 0">
        <xsl:value-of select="OperationalEnergy/HeavyFuel"/>
        <xsl:value-of select="$spacing" />
        <xsl:value-of select="OperationalEnergy/HeavyFuelUnit"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$defaultOEValue"/>
        <xsl:value-of select="$spacing" />
        <xsl:value-of select="OperationalEnergy/HeavyFuelUnit"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Diesel (Industrial Boiler)</xsl:text>
    <xsl:value-of select="$twotabs" />
    <xsl:choose>
      <xsl:when test="string-length(OperationalEnergy/Diesel) > 0">
        <xsl:value-of select="OperationalEnergy/Diesel"/>
        <xsl:value-of select="$spacing" />
        <xsl:value-of select="OperationalEnergy/DieselUnit"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$defaultOEValue"/>
        <xsl:value-of select="$spacing" />
        <xsl:value-of select="OperationalEnergy/DieselUnit"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$linebig-decorator" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Window Information</xsl:text>
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Glazing Type</xsl:text>
    <xsl:value-of select="$onetab" />
    <xsl:value-of select="$defaultNoLabel" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Frame Material</xsl:text>
    <xsl:value-of select="$onetab" />
    <xsl:value-of select="$defaultNoLabel" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Frame Type</xsl:text>
    <xsl:value-of select="$onetab" />
    <xsl:value-of select="$defaultNoLabel" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$linebig-decorator" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Door Information</xsl:text>
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Door Material</xsl:text>
    <xsl:value-of select="$onetab" />
    <xsl:value-of select="$defaultNoLabel" />
    <xsl:value-of select="$line-separator" />
    <xsl:text disable-output-escaping="yes">Frame Material</xsl:text>
    <xsl:value-of select="$onetab" />
    <xsl:value-of select="$defaultNoLabel" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$linebig-decorator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:value-of select="$line-separator" />
    <xsl:for-each select="GroupList/anyType">
      <xsl:if test="ID=1">
        <xsl:value-of select="$linebig-decorator" />
        <xsl:text disable-output-escaping="yes">Assembly Group: Foundations</xsl:text>
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$linebig-decorator" />
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcreteFootingAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Footing</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Length(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Thickness(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Rebar</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Concrete(MPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>          
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Z) > 0">
              <xsl:value-of select="Z"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Rebar) > 0">
              <xsl:value-of select="Rebar"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(ConcreteType) > 0">
              <xsl:value-of select="ConcreteType"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcreteSlabOnGradeAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Slab On Grade</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Length(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Thickness(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Concrete(MPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Length) > 0">
              <xsl:value-of select="Length"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Width) > 0">
              <xsl:value-of select="Width"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(ThicknessValue) > 0">
              <xsl:value-of select="ThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(ConcreteTypeValue) > 0">
              <xsl:value-of select="ConcreteTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="ID=2">
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$linebig-decorator" />
        <xsl:text disable-output-escaping="yes">Assembly Group: Walls</xsl:text>
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$linebig-decorator" />
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'CustomWall']/WallsCollection/Assembly[@xsi:type = 'ConcreteBlockAssembly']">
           <xsl:if test="position()=1">
             <xsl:value-of select="$line-separator" />
             <xsl:value-of select="$linebig-decorator" />
             <xsl:value-of select="$line-separator" />
             <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Block Wall</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
             <xsl:value-of select="$line-separator" />
             <xsl:value-of select="$line-separator" />
             <xsl:value-of select="$assemblyInstances" />
             <xsl:value-of select="$line-separator" />
             <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Height (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Length(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Openings(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Num.Openings</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">	Rebar Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(TotalOpeningArea) > 0">
              <xsl:value-of select="TotalOpeningArea"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(NumberOfWindows) > 0">
              <xsl:value-of select="NumberOfWindows"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">External</xsl:text>
          <!--Check this-->
          <!--check this-->
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(Rebar) > 0">
              <xsl:value-of select="Rebar"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'CustomWall']/WallsCollection/Assembly[@xsi:type = 'CastInPlaceAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Cast In Place Wall</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Height (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Length(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Openings(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Num.Openings</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Concrete Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Rebar Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Height) > 0">
              <xsl:value-of select="Height"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Length) > 0">
              <xsl:value-of select="Length"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(TotalOpeningArea) > 0">
              <xsl:value-of select="TotalOpeningArea"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(NumberOfWindows) > 0">
              <xsl:value-of select="NumberOfWindows"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">External</xsl:text>
          <!--Check this-->
          <!--check this-->
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(Thickness) > 0">
              <xsl:value-of select="Thickness"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(ConcreteTypeID) > 0">
              <xsl:value-of select="ConcreteTypeID"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--Replace this with concrete Type?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Rebar) > 0">
              <xsl:value-of select="Rebar"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'CustomWall']/WallsCollection/Assembly[@xsi:type = 'ConcreteTiltUpAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Tilt-Up Wall</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Height (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Length(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Openings(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Num.Openings</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Concrete Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Rebar Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(TotalOpeningArea) > 0">
              <xsl:value-of select="TotalOpeningArea"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(NumberOfWindows) > 0">
              <xsl:value-of select="NumberOfWindows"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">External</xsl:text>
          <!--Check this-->
          <!--check this-->
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(Thickness) > 0">
              <xsl:value-of select="Thickness"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(ConcreteType) > 0">
              <xsl:value-of select="ConcreteType"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Rebar) > 0">
              <xsl:value-of select="Rebar"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'CustomWall']/WallsCollection/Assembly[@xsi:type = 'CurtainAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Curtain Wall</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Length</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Height</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Percent Viewable Glazing</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Percent Opaque Glazing</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Percent Spandrel Panel</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Percent Stress </xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Skin Panel	With Insulated Backpan</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Length) > 0">
              <xsl:value-of select="Length"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(Height) > 0">
              <xsl:value-of select="Height"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(ViewableGlazing) > 0">
              <xsl:value-of select="ViewableGlazing"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$fourtabs" />
          <xsl:choose>
            <xsl:when test="string-length(OpaqueGlazing) > 0">
              <xsl:value-of select="OpaqueGlazing"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(SpandrelPanel) > 0">
              <xsl:value-of select="SpandrelPanel"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:value-of select="$default2DigitDecValue" />
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(HasInsulatedBackpan) > 0">
              <xsl:value-of select="HasInsulatedBackpan"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'CustomWall']/WallsCollection/Assembly[@xsi:type = 'InsulatedConcreteFormAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Insulated Concrete Form Wall</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Height (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Length(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Openings(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Num.Openings</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(TotalOpeningArea) > 0">
              <xsl:value-of select="TotalOpeningArea"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(NumberOfWindows) > 0">
              <xsl:value-of select="NumberOfWindows"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">External</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(ThicknessCalculationValue) > 0">
              <xsl:value-of select="ThicknessCalculationValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this - thicknessid or thicknesscalculationvalue or lookup-->
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'CustomWall']/WallsCollection/Assembly[@xsi:type = 'SteelStudAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Steel Stud Wall</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Height (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Length(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Openings(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Num.Openings</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Sheathing</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Stud Spacing</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Stud Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Stud Weight</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(TotalOpeningArea) > 0">
              <xsl:value-of select="TotalOpeningArea"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
            <xsl:choose>
            <xsl:when test="string-length(NumberOfWindows) > 0">
              <xsl:value-of select="NumberOfWindows"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">External</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(SheathingType) > 0">
              <xsl:value-of select="SheathingType"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(StudSpacing) > 0">
              <xsl:value-of select="StudSpacing"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(StudThickness) > 0">
              <xsl:value-of select="StudThickness"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(StudWeight) > 0">
              <xsl:value-of select="StudWeight"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'CustomWall']/WallsCollection/Assembly[@xsi:type = 'WoodStudAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Wood Stud Wall</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Height (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Length(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Openings(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Num.Openings</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$threetabs" />
          <xsl:text disable-output-escaping="yes">Sheathing</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Stud Spacing</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Stud Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Lumber Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(TotalOpeningArea) > 0">
              <xsl:value-of select="TotalOpeningArea"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(NumberOfWindows) > 0">
              <xsl:value-of select="NumberOfWindows"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$threetabs" />
          <xsl:text disable-output-escaping="yes">External</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(SheathingType) > 0">
              <xsl:value-of select="SheathingType"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(StudSpacing) > 0">
              <xsl:value-of select="StudSpacing"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(StudThickness) > 0">
              <xsl:value-of select="StudThickness"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(StudType) > 0">
              <xsl:value-of select="StudType"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="ID=3">
        <xsl:value-of select="$linebig-decorator" />
        <xsl:text disable-output-escaping="yes">Assembly Group: Beams and Columns</xsl:text>
        <!-- Bay Size (m)	Floor-to-Floor Height (m)	Live Load (m)	No. of Bays(mm)	No. of Rows	Supported Span-->
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$linebig-decorator" />
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'MixedColumnsAndBeamsAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Mixed Beams and Columns</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Bay Size (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor-to-Floor Height (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">No. of Bays</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">No. of Rows</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Supported Span</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(BaySize) > 0">
              <xsl:value-of select="BaySize"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Height) > 0">
              <xsl:value-of select="Height"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$fourtabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoad) > 0">
              <xsl:value-of select="LiveLoad"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Beams) > 0">
              <xsl:value-of select="Beams"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Columns) > 0">
              <xsl:value-of select="Columns"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!--check this-->
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="ID=4">
        <xsl:value-of select="$linebig-decorator" />
        <xsl:text disable-output-escaping="yes">Assembly Group: Floors</xsl:text>
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$linebig-decorator" />
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcreteHollowCoreAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Hollow Core Floor</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Bay Size(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">No. of Bays</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Span(m)</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Live Load(kPa)</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(BaySize) > 0">
              <xsl:value-of select="BaySize"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Bays) > 0">
              <xsl:value-of select="Bays"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:text disable-output-escaping="yes">Floor</xsl:text>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcreteSuspendedSlabAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Flat Plate on Columns Floor</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Bay Size(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">No. of Bays</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Span(m)</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Live Load(kPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Flr-Flr Height</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(BaySize) > 0">
              <xsl:value-of select="BaySize"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Bays) > 0">
              <xsl:value-of select="Bays"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Floor</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- only number of rows in the athena3.0 save as text-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcreteParkingGarageAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Flat Plate with Drop Panels</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Number of Rows</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Concrete Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Rows) > 0">
              <xsl:value-of select="Rows"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(ConcreteTypeValue) > 0">
              <xsl:value-of select="ConcreteTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Floor</xsl:text>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcretePrecastDoubleTAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Precast Double T Floor</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Bay Size(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">No. of Bays</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Span(m)</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Live Load(kPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(BaySize) > 0">
              <xsl:value-of select="BaySize"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Bays) > 0">
              <xsl:value-of select="Bays"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Floor</xsl:text>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- Span (m)	Floor Width(m)	Live Load	Type	Decking Type	Decking Thickness	Truss Type-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'LightFrameWoodTrussAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Light Frame Wood Trusses</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Truss Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(TrussTypeValue) > 0">
              <xsl:value-of select="TrussTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!--Span (m)	Floor Width(m)	Live Load	Type	Topping-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'OpenWebSteelJoistAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	OWSJ and Steel Decking with Concrete Topping</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Topping</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(ConcreteToppingTypeValue) > 0">
              <xsl:value-of select="ConcreteToppingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!--Span (m)	Floor Width(m)	Live Load	Type-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'GlulamJoistAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Glulam Joists with Plank Decking</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Floor</xsl:text>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- Span (m)	Floor Width(m)	Live Load	Type	Decking Type	DeckingThickness-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'WoodJoistAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Wood Joists with Plywood Decking</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- Floor Length (m)	Floor Width(mm)	Decking Type	Decking Thickness 	Steel Gauge	Joist Type	Joist Spacing Type-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'SteelJoistAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Steel Joists with Plywood/OSB Decking</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Floor Length (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Steel Gauge</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Joist Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Joist Spacing Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(SteelGaugeValue) > 0">
              <xsl:value-of select="SteelGaugeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(JoistTypeValue) > 0">
              <xsl:value-of select="JoistTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(JoistSpacingValue) > 0">
              <xsl:value-of select="JoistSpacingValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!--Span (m)	Floor Width(m)	Live Load	Type	Decking Type	Decking Thickness -->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'WoodChordAndSteelWebTrussAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Wood Chord / Steel Web with Plywood Decking</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
           <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- Span (m)	Floor Width(m)	Live Load	Type	Decking Type	Decking Thickness	Web Type	Web Thickness	Flange Type	Flange Size-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'WoodIJoistAssembly']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Wood 'I' Joists with Plywood/OSB Decking</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Web Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Web Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Flange Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Flange Size</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(WebTypeValue) > 0">
              <xsl:value-of select="WebTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(WebThicknessValue) > 0">
              <xsl:value-of select="WebThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(FlangeTypeValue) > 0">
              <xsl:value-of select="FlangeTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(FlangeSizeValue) > 0">
              <xsl:value-of select="FlangeSizeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="ID=5">
        <xsl:value-of select="$linebig-decorator" />
        <xsl:text disable-output-escaping="yes">Assembly Group: Roofs</xsl:text>
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$linebig-decorator" />
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcreteHollowCoreAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Hollow Core Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Bay Size(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">No. of Bays</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Span(m)</xsl:text>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Live Load(kPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(BaySize) > 0">
              <xsl:value-of select="BaySize"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Bays) > 0">
              <xsl:value-of select="Bays"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Roof</xsl:text>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcreteSuspendedSlabAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Flat Plate on Columns Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Bay Size(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">No. of Bays</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Span(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(kPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Flr-Flr Height</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(BaySize) > 0">
              <xsl:value-of select="BaySize"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Bays) > 0">
              <xsl:value-of select="Bays"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Roof</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- only number of rows in the athena3.0 save as text-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcreteParkingGarageAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Flat Plate with Drop Panels Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Number of Rows</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Concrete Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Rows) > 0">
              <xsl:value-of select="Rows"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(ConcreteTypeValue) > 0">
              <xsl:value-of select="ConcreteTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Roof</xsl:text>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'ConcretePrecastDoubleTAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Concrete Precast Double T Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Bay Size(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">No. of Bays</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Span(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(kPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(BaySize) > 0">
              <xsl:value-of select="BaySize"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Bays) > 0">
              <xsl:value-of select="Bays"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Roof</xsl:text>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- Span (m)	Floor Width(m)	Live Load	Type	Decking Type	Decking Thickness	Truss Type-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'LightFrameWoodTrussAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Light Frame Wood Trusses Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Truss Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(TrussTypeValue) > 0">
              <xsl:value-of select="TrussTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!--Span (m)	Floor Width(m)	Live Load	Type	Topping-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'OpenWebSteelJoistAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	OWSJ and Steel Decking with Concrete Topping Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Topping</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(ConcreteToppingTypeValue) > 0">
              <xsl:value-of select="ConcreteToppingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$onetab" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!--Span (m)	Floor Width(m)	Live Load	Type-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'GlulamJoistAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Glulam Joists with Plank Decking Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:text disable-output-escaping="yes">Roof</xsl:text>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- Span (m)	Floor Width(m)	Live Load	Type	Decking Type	DeckingThickness-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'WoodJoistAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Wood Joists with Plywood Decking</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- Floor Length (m)	Floor Width(mm)	Decking Type	Decking Thickness 	Steel Gauge	Joist Type	Joist Spacing Type-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'SteelJoistAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Steel Joists with Plywood/OSB Decking Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Floor Length (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Steel Gauge</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Joist Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Joist Spacing Type</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(Y) > 0">
              <xsl:value-of select="Y"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(SteelGaugeValue) > 0">
              <xsl:value-of select="SteelGaugeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(JoistTypeValue) > 0">
              <xsl:value-of select="JoistTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(JoistSpacingValue) > 0">
              <xsl:value-of select="JoistSpacingValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!--Span (m)	Floor Width(m)	Live Load	Type	Decking Type	Decking Thickness -->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'WoodChordAndSteelWebTrussAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Wood Chord / Steel Web with Plywood Decking Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
        <!-- Span (m)	Floor Width(m)	Live Load	Type	Decking Type	Decking Thickness	Web Type	Web Thickness	Flange Type	Flange Size-->
        <xsl:for-each select="AssemblyList/anyType[@xsi:type = 'WoodIJoistAssemblyRoof']">
          <xsl:if test="position()=1">
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:text disable-output-escaping="yes">Assembly Type:	Wood 'I' Joists with Plywood/OSB Decking Roof</xsl:text>
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$linebig-decorator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$assemblyInstances" />
            <xsl:value-of select="$line-separator" />
            <xsl:value-of select="$line-separator" />
          </xsl:if>
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="AssemblyUserName" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$linesmall-decorator" />
          <xsl:value-of select="$line-separator" />
          <xsl:value-of select="$line-separator" />
          <xsl:text disable-output-escaping="yes">Span (m)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Floor Width(mm)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Live Load(KPa)</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Decking Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Web Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Web Thickness</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Flange Type</xsl:text>
          <xsl:value-of select="$onetab" />
          <xsl:text disable-output-escaping="yes">Flange Size</xsl:text>
          <xsl:value-of select="$line-separator" />
          <xsl:choose>
            <xsl:when test="string-length(Span) > 0">
              <xsl:value-of select="Span"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <!-- Need span?-->
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(X) > 0">
              <xsl:value-of select="X"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(LiveLoadValue) > 0">
              <xsl:value-of select="LiveLoadValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingTypeValue) > 0">
              <xsl:value-of select="DeckingTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(DeckingThicknessValue) > 0">
              <xsl:value-of select="DeckingThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$threetabs" />
          <xsl:choose>
            <xsl:when test="string-length(WebTypeValue) > 0">
              <xsl:value-of select="WebTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(WebThicknessValue) > 0">
              <xsl:value-of select="WebThicknessValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(FlangeTypeValue) > 0">
              <xsl:value-of select="FlangeTypeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$twotabs" />
          <xsl:choose>
            <xsl:when test="string-length(FlangeSizeValue) > 0">
              <xsl:value-of select="FlangeSizeValue"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$default2DigitDecValue"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$line-separator" />
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="ID=6">
        <xsl:value-of select="$linebig-decorator" />
        <xsl:text disable-output-escaping="yes">Assembly Group: Extra Materials</xsl:text>
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$linebig-decorator" />
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$line-separator" />
        <xsl:text disable-output-escaping="yes">Assembly Type:	Extra Basic Materials</xsl:text>
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$linebig-decorator" />
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$line-separator" />
        <xsl:text disable-output-escaping="yes">Assembly Instances: </xsl:text>
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$twotabs" />
        <xsl:text disable-output-escaping="yes">Extra Bill of Materials</xsl:text>
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$twotabs" />
        <xsl:value-of select="$linesmall-decorator" />
        <xsl:value-of select="$line-separator" />
        <xsl:text disable-output-escaping="yes">Extra Basic Materials that have been added</xsl:text>
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$line-separator" />
        <xsl:value-of select="$line-separator" />
        <xsl:for-each select=".//MaterialList">
          <xsl:if test="Value>0">
            <xsl:value-of select="ext:ParseMaterial(Id, Value)"/>
            <xsl:value-of select="$line-separator" />
          </xsl:if>
        </xsl:for-each>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
</xsl:stylesheet>

